/*
Copyright (c) 2003-2011, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.html or http://ckeditor.com/license
*/

CKEDITOR.plugins.setLang( 'placeholder', 'en',
{
	placeholder :
	{
		title		: 'Placeholder Properties',
		toolbar		: 'Create Placeholder',
		text		: 'Placeholder Text',
		edit		: 'Edit Placeholder',
		textMissing	: 'The placeholder must contain text.'
	}
});
